==> estateplat-common-1.2.4-20250218.100055-1286-sources.jar: cn/gtmap/estateplat/model/server/core/BdcDadaModify.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

@Entity
@Table(name = "bdc_data_modify")
public class BdcDadaModify implements Serializable {
    @Id
    @Column
    private String id;//id
    @Column
    private String proid;//项目id
    @Column
    private String xmzt;//项目状态
    @Column
    private String bdcqzh;//不动产权证号
    @Column
    private String bdcdyh;//不动产单元号
    @Column
    private String bdlx;//表单类型
    @Column
    private String cjr;//创建人
    @Column
    private Date cjsj;//创建时间
    @Column
    private String bjr;//办结人
    @Column
    private Date bjsj;//办结时间
    @Column
    private String oldDataJson;//原始数据
    @Column
    private String newDataJson;//修改后数据
    @Column
    private String compareDataJson;//对比后数据

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getXmzt() {
        return xmzt;
    }

    public void setXmzt(String xmzt) {
        this.xmzt = xmzt;
    }

    public String getCjr() {
        return cjr;
    }

    public void setCjr(String cjr) {
        this.cjr = cjr;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public String getBjr() {
        return bjr;
    }

    public void setBjr(String bjr) {
        this.bjr = bjr;
    }

    public Date getBjsj() {
        return bjsj;
    }

    public void setBjsj(Date bjsj) {
        this.bjsj = bjsj;
    }

    public String getOldDataJson() {
        return oldDataJson;
    }

    public void setOldDataJson(String oldDataJson) {
        this.oldDataJson = oldDataJson;
    }

    public String getNewDataJson() {
        return newDataJson;
    }

    public void setNewDataJson(String newDataJson) {
        this.newDataJson = newDataJson;
    }

    public String getCompareDataJson() {
        return compareDataJson;
    }

    public void setCompareDataJson(String compareDataJson) {
        this.compareDataJson = compareDataJson;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdlx() {
        return bdlx;
    }

    public void setBdlx(String bdlx) {
        this.bdlx = bdlx;
    }
}

==> estateplat-common-1.2.4-20250228.064212-1289-sources.jar: cn/gtmap/estateplat/model/server/core/BdcDadaModify.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

@Entity
@Table(name = "bdc_data_modify")
public class BdcDadaModify implements Serializable {
    @Id
    @Column
    private String id;//id
    @Column
    private String proid;//项目id
    @Column
    private String xmzt;//项目状态
    @Column
    private String bdcqzh;//不动产权证号
    @Column
    private String bdcdyh;//不动产单元号
    @Column
    private String bdlx;//表单类型
    @Column
    private String cjr;//创建人
    @Column
    private Date cjsj;//创建时间
    @Column
    private String bjr;//办结人
    @Column
    private Date bjsj;//办结时间
    @Column
    private String oldDataJson;//原始数据
    @Column
    private String newDataJson;//修改后数据
    @Column
    private String compareDataJson;//对比后数据
    @Column
    private String cbdbsj;//重报登簿数据

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getXmzt() {
        return xmzt;
    }

    public void setXmzt(String xmzt) {
        this.xmzt = xmzt;
    }

    public String getCjr() {
        return cjr;
    }

    public void setCjr(String cjr) {
        this.cjr = cjr;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public String getBjr() {
        return bjr;
    }

    public void setBjr(String bjr) {
        this.bjr = bjr;
    }

    public Date getBjsj() {
        return bjsj;
    }

    public void setBjsj(Date bjsj) {
        this.bjsj = bjsj;
    }

    public String getOldDataJson() {
        return oldDataJson;
    }

    public void setOldDataJson(String oldDataJson) {
        this.oldDataJson = oldDataJson;
    }

    public String getNewDataJson() {
        return newDataJson;
    }

    public void setNewDataJson(String newDataJson) {
        this.newDataJson = newDataJson;
    }

    public String getCompareDataJson() {
        return compareDataJson;
    }

    public void setCompareDataJson(String compareDataJson) {
        this.compareDataJson = compareDataJson;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdlx() {
        return bdlx;
    }

    public void setBdlx(String bdlx) {
        this.bdlx = bdlx;
    }

    public String getCbdbsj() {
        return cbdbsj;
    }

    public void setCbdbsj(String cbdbsj) {
        this.cbdbsj = cbdbsj;
    }
}
